Overview — stanpy 0.2.2 documentation

# Overview

Structural analysis libary in python

- Free software: MIT license

## Installation

    pip install stanpy

You can also install the in-development version with:

    pip install git+ssh://git@https://github.com/davidnaizhezhou/stanpy@main

## Documentation

https://stanpy-dev.david-zhou.org/

## Development

To run all the tests run:

    tox

Note, to combine the coverage data from all the tox environments run:

previous

Welcome to stanpy's documentation!

next

Getting started